@@ -182,7 +182,7 @@ qBEINF <- function(p, mu = 0.5, sigma = 0.1, nu = 0.1, tau = 0.1,
             stop(paste("nu must greated than 0", "\n", ""))           
          if (any(tau <= 0) )  
             stop(paste("tau must greated than 0", "\n", "")) 
-         if (any(p <= 0) | any(p >= 1))  
+         if (any(p < 0) | any(p > 1))  
             stop(paste("p must be between 0 and 1", "\n", ""))    
          if (log.p==TRUE) p <- exp(p) else p <- p
          if (lower.tail==TRUE) p <- p else p <- 1-p
