@@ -34,7 +34,9 @@ WEI3 <- function (mu.link="log", sigma.link="log")
                                     sigma <-  rep(s.Y.s,length(y))}),
               mu.valid = function(mu) all(mu > 0) , 
            sigma.valid = function(sigma)  all(sigma > 0), 
-               y.valid = function(y)  all(y > 0)
+               y.valid = function(y)  all(y > 0),
+                  mean = function(mu, sigma) mu,
+              variance = function(mu, sigma) (mu * (gamma(1/sigma + 1))^-1)^2  * (gamma(2/sigma + 1) - (gamma(1/sigma + 1))^2)
           ),
             class = c("gamlss.family","family"))
 }
