@@ -53,7 +53,10 @@ ZIP <- function (mu.link = "log", sigma.link = "logit")
    sigma.initial = expression(sigma <-rep(0.1, length(y))), 
       mu.valid = function(mu) all(mu > 0) , 
    sigma.valid = function(sigma)  all(sigma > 0 & sigma < 1), 
-       y.valid = function(y)  all(y >= 0)
+       y.valid = function(y)  all(y >= 0),
+          mean = function(mu, sigma) (1 - sigma) * mu,
+      variance = function(mu, sigma) mu * (1 - sigma) * (1 + mu * sigma)
+
           ),
             class = c("gamlss.family","family"))
 }
